(ns clojsa.handler
  (:require [clojsa.saparser :as parser]
            [clojsa.saclient :as client]
            [clojsa.views :as views]
            [compojure.core :refer :all]
            [compojure.route :as route]
            [compojure.coercions :refer [as-int]]
            [ring.middleware.defaults :refer [wrap-defaults site-defaults]]
            [ring.middleware.session :refer [wrap-session]]
            [ring.middleware.session.cookie :refer (cookie-store)]))

(def session-cookie-store (cookie-store {:key "b91c62d40a1fd146"}))

(defroutes app-routes
  (GET "/" request (views/index-page request))
  (GET "/login" {session :session}
       (let [login-cookies (client/do-login)]
         {:status 302
          :headers {"Location" "/thread/3814875?page=29"}
          :session (assoc session :cookies login-cookies)}))

  (GET "/thread/:id" [id :<< as-int
                      page :<< as-int
                      :as {session :session}]
       (let [thread (assoc (parser/get-thread session id page) :page page)
             count (:count session 0)
             session (assoc session :count (inc count))]
         {:body (views/thread-page thread session)
          :headers {"Content-Type" "text/html; charset=utf-8"}
          :session session}))

  (route/not-found "Not Found"))

(def app
  (-> app-routes
      (wrap-defaults site-defaults)
      (wrap-session {:cookie-name "clojsa-session"
                     :cookie-attrs {:max-age (* 7 24 3600)}
                     :store session-cookie-store})))
