(ns clojsa.views
  (:use [hiccup core page])
  (:require
            [clojure.string :as string]
            [clojure.java.io :as io]
            [cheshire.core :as json]))


(defn header-fragment []
  (html
   [:nav]))

(defn main-template [opts & insert-body-here]
  (html5
   {:lang "de"}
   [:head
    [:meta {:charset "utf-8"}]
    [:meta {:http-equiv "x-ua-compatible" :content "ie=edge"}]
    [:meta {:name "viewport" :content "width=device-width, initial-scale=1"}]
    [:title (get opts :title "clojsa")]
    (include-css "/css/bulma.min.css")
    (include-css "/css/style.css")
    (include-js "/js/htmx.min.js")]
   [:body
    {:hx-boost "false"}
    [:header
     (header-fragment)]
    [:main
     insert-body-here]
    (include-js "/js/main.js")]))

(defn index-page [req]
  (main-template
   {}
   [:div.container
    [:pre.output
     [:code (with-out-str (clojure.pprint/pprint req))]]]))

(defn paginate [id cur last]
  [:nav.container.box.pagination {:hx-boot "false"}
   [:a.pagination-previous
    {:href (format "/thread/%d?page=%d" id (dec cur))} "<"]
   [:a.pagination-next
    {:href (format "/thread/%s?page=%d" id (inc cur))} ">"]
   [:ul.pagination-list
    [:li
     [:a.pagination-link
      {:href (format "/thread/%d?page=%d" id 1)} (str 1)]]
    [:li
     [:span.pagination-ellipsis "&hellip;"]]
    (for [i (range (- cur 2) (+ cur 3))]
      [:li
       [:a.pagination-link
        {:href (format "/thread/%d?page=%d" id i)
         :class (when (= i cur) "is-current")} (str i)]])
    [:li
     [:span.pagination-ellipsis "&hellip;"]]
    [:li
     [:a.pagination-link
      {:href (format "/thread/%d?page=%d" id last)} (str last)]]]])

(defn thread-page [thread session]
  (let [{:keys [id title page page-count content]} thread]
    (main-template
     {:title title}
     [:div.container
      [:pre.output
       [:code (with-out-str (clojure.pprint/pprint session))]]
      [:h1.is-size-3.mb-4 title]]
     [:section.thread
      (for [post content]
        [:article.container.box
         [:div.tile.is-ancestor
          [:aside.userinfo.tile.is-3.is-parent
           (:ui post)]
          [:main.postbody.content.tile.is-9.is-parent.is-vertical
           [:div.tile.is-child
            (:pb post)]
           [:div.level.tile.is-child.is-12
            [:div.level-right
             [:span.postdate.level-item
              (:pd post)]]]]]])]
     [:section
      (paginate id page page-count)])))
